@@ -1,4 +1,5 @@
-#include "spvm_native.h"
+// Windows 8.1+
+#define _WIN32_WINNT 0x0603
 
 #include "spvm_native.h"
 
@@ -18,6 +19,8 @@
 # include <netinet/udp.h>
 # include <sys/un.h>
 # include <arpa/inet.h>
+# include <netdb.h>
+# include <poll.h>
 #endif
 
 static const char* FILE_NAME = "Sys/Socket/Constant.c";
@@ -2511,3 +2514,27 @@ int32_t SPVM__Sys__Socket__Constant__IN6ADDR_LOOPBACK(SPVM_ENV* env, SPVM_VALUE*
 
 }
 
+int32_t SPVM__Sys__Socket__Constant__NI_MAXHOST(SPVM_ENV* env, SPVM_VALUE* stack) {
+
+#ifdef NI_MAXHOST
+  stack[0].ival = NI_MAXHOST;
+  return 0;
+#else
+  env->die(env, stack, "NI_MAXHOST is not defined on this system", FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+#endif
+
+}
+
+int32_t SPVM__Sys__Socket__Constant__NI_MAXSERV(SPVM_ENV* env, SPVM_VALUE* stack) {
+
+#ifdef NI_MAXSERV
+  stack[0].ival = NI_MAXSERV;
+  return 0;
+#else
+  env->die(env, stack, "NI_MAXSERV is not defined on this system", FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+#endif
+
+}
+
