@@ -84,6 +84,12 @@ Sets C<sin_port>.
 
 The size of C<struct sockaddr_in>.
 
+=head2 clone
+
+  method clone : Sys::Socket::Sockaddr::In () {
+
+Clones this object.
+
 =head1 Copyright & License
 
 Copyright 2022-2022 Yuki Kimoto, all rights reserved.
